@@ -2,6 +2,9 @@ import unittest
 import os
 import manual_rps
 from inspect import getsource
+import spacy
+from urllib.request import urlopen
+
 
 class CompVisTestCase(unittest.TestCase):
     
@@ -29,6 +32,18 @@ class CompVisTestCase(unittest.TestCase):
         self.assertIn("get_user_choice", func, "The function play should call get_user_choice")
         self.assertIn("get_winner", func, "The function play should call get_winner")
 
+    def test_presence_readme(self):
+        self.assertIn('README.md', os.listdir('.'), 'You should have a README.md file in your project folder')
+        with open('README.md', 'r') as f:
+            readme = f.read()
+        self.assertGreater(len(readme), 1500, 'The README.md file should be at least 1500 characters long')
+        nlp = spacy.load("en_core_web_md")
+        documentation = urlopen("https://aicore-files.s3.amazonaws.com/documentation.md")
+        tdata = str(documentation.read(), 'utf-8')
+        doc_1 = nlp(readme)
+        doc_2 = nlp(tdata)
+        self.assertLessEqual(doc_1.similarity(doc_2), 0.975, 'The README.md file is almost identical to the one provided in the template')
+
 
 if __name__ == '__main__':
 
