@@ -20,12 +20,10 @@ if 'milestone_1.txt' in os.listdir('.'):
     elif 'test_model_presence' in errors:
         # mark_incomplete(task2_id, message='There is no hangman_solution.py file inside the hangman folder')
         mark_incomplete(task1_id)
-        mark_incomplete(task2_id)
-        print(errors['test_model_presence'])
+        mark_incomplete(task2_id, message=errors['test_model_presence'])
     # Check if they are identical
     elif 'test_readme_presence' in errors:
-        mark_incomplete(task3_id)
-        print(errors['test_readme_presence'])
+        mark_incomplete(task3_id, message=errors['test_readme_presence'])
 
 else:
     mark_incomplete(task1_id)
